==> pf4-component-mapper-3.4.1.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { FormGroup as Pf4FormGroup } from "@patternfly/react-core/dist/esm/components/Form/FormGroup.js";
import { TextContent } from "@patternfly/react-core/dist/esm/components/Text/TextContent.js";
import { Text } from "@patternfly/react-core/dist/esm/components/Text/Text.js";
import PropTypes from 'prop-types';
import showError from '../show-error/show-error';

var FormGroup = function FormGroup(_ref) {
  var label = _ref.label,
      isRequired = _ref.isRequired,
      helperText = _ref.helperText,
      meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      children = _ref.children,
      id = _ref.id,
      FormGroupProps = _ref.FormGroupProps;
  return /*#__PURE__*/React.createElement(Pf4FormGroup, _extends({
    isRequired: isRequired,
    label: !hideLabel && label,
    fieldId: id,
    helperText: meta.touched && meta.warning || helperText,
    helperTextInvalid: meta.error || meta.submitError
  }, showError(meta, validateOnMount), FormGroupProps), description && /*#__PURE__*/React.createElement(TextContent, null, /*#__PURE__*/React.createElement(Text, {
    component: "small"
  }, description)), children);
};

FormGroup.propTypes = {
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  meta: PropTypes.object.isRequired,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  id: PropTypes.string.isRequired,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired,
  FormGroupProps: PropTypes.object
};
export default FormGroup;

==> pf4-component-mapper-3.17.0.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { FormGroup as Pf4FormGroup } from "@patternfly/react-core/dist/esm/components/Form/FormGroup.js";
import { TextContent } from "@patternfly/react-core/dist/esm/components/Text/TextContent.js";
import { Text } from "@patternfly/react-core/dist/esm/components/Text/Text.js";
import PropTypes from 'prop-types';
import showError from '../show-error/show-error';

var FormGroup = function FormGroup(_ref) {
  var label = _ref.label,
      isRequired = _ref.isRequired,
      helperText = _ref.helperText,
      meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      children = _ref.children,
      id = _ref.id,
      FormGroupProps = _ref.FormGroupProps;
  return /*#__PURE__*/React.createElement(Pf4FormGroup, _extends({
    isRequired: isRequired,
    label: !hideLabel && label,
    fieldId: id,
    helperText: (meta.touched || validateOnMount) && meta.warning || helperText,
    helperTextInvalid: meta.error || meta.submitError
  }, showError(meta, validateOnMount), FormGroupProps), description && /*#__PURE__*/React.createElement(TextContent, null, /*#__PURE__*/React.createElement(Text, {
    component: "small"
  }, description)), children);
};

FormGroup.propTypes = {
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  meta: PropTypes.object.isRequired,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  id: PropTypes.string.isRequired,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired,
  FormGroupProps: PropTypes.object
};
export default FormGroup;
